)]}'
{"nova/virt/libvirt/connection.py":[{"author":{"_account_id":2271,"name":"Michael Still","email":"mikal@stillhq.com","username":"mikalstill"},"change_message_id":"5bc5ee2039c5387a302a47da13cf0634d58872cb","unresolved":false,"context_lines":[{"line_number":846,"context_line":"                    if not os.path.exists(cow_base):"},{"line_number":847,"context_line":"                        libvirt_utils.copy_image(base, cow_base)"},{"line_number":848,"context_line":"                        disk.extend(cow_base, size)"},{"line_number":849,"context_line":"                libvirt_utils.create_cow_image(cow_base, target)"},{"line_number":850,"context_line":"            elif not generating:"},{"line_number":851,"context_line":"                libvirt_utils.copy_image(base, target)"},{"line_number":852,"context_line":"                # Resize after the copy, as it\u0027s usually much faster"}],"source_content_type":"text/x-python","patch_set":1,"id":"AAAAEn%2F%2F%2F%2Fk%3D","line":849,"updated":"2012-02-02 02:21:56.000000000","message":"I\u0027m pretty sure this is going to break the cache cleanup code in https://review.openstack.org/#change,2902 . That\u0027s not a big problem, but its going to require tweaks and retesting of one or the other depending on what is merged first.","commit_id":"bfd7a93910857faf14eff45a5c8fc6389a58b364"},{"author":{"_account_id":1812,"name":"p-draigbrady","email":"P@draigBrady.com","username":"p-draigbrady"},"change_message_id":"ed4a3255169e2dc79889232d5f0de7eabea95477","unresolved":false,"context_lines":[{"line_number":846,"context_line":"                    if not os.path.exists(cow_base):"},{"line_number":847,"context_line":"                        libvirt_utils.copy_image(base, cow_base)"},{"line_number":848,"context_line":"                        disk.extend(cow_base, size)"},{"line_number":849,"context_line":"                libvirt_utils.create_cow_image(cow_base, target)"},{"line_number":850,"context_line":"            elif not generating:"},{"line_number":851,"context_line":"                libvirt_utils.copy_image(base, target)"},{"line_number":852,"context_line":"                # Resize after the copy, as it\u0027s usually much faster"}],"source_content_type":"text/x-python","patch_set":1,"id":"AAAAEn%2F%2F%2F8M%3D","line":849,"in_reply_to":"AAAAEn%2F%2F%2F%2Fk%3D","updated":"2012-02-02 10:23:07.000000000","message":"True. I\u0027ll keep that in mind.","commit_id":"bfd7a93910857faf14eff45a5c8fc6389a58b364"},{"author":{"_account_id":67,"name":"Vish Ishaya","email":"vishvananda@gmail.com","username":"vishvananda"},"change_message_id":"0ea37930f65c8a065a2223d56feb3f15a290a3f3","unresolved":false,"context_lines":[{"line_number":932,"context_line":"                                  project_id\u003dinst[\u0027project_id\u0027])"},{"line_number":933,"context_line":""},{"line_number":934,"context_line":"        root_fname \u003d hashlib.sha1(str(disk_images[\u0027image_id\u0027])).hexdigest()"},{"line_number":935,"context_line":"        size \u003d inst[\u0027root_gb\u0027] * 1024 * 1024 * 1024"},{"line_number":936,"context_line":""},{"line_number":937,"context_line":"        inst_type_id \u003d inst[\u0027instance_type_id\u0027]"},{"line_number":938,"context_line":"        inst_type \u003d instance_types.get_instance_type(inst_type_id)"}],"source_content_type":"text/x-python","patch_set":1,"id":"AAAAEn%2F%2F%2F9c%3D","line":935,"updated":"2012-02-02 07:24:15.000000000","message":"seems odd to multiply the size out here and then redivide it in the method call, but I guess we have to support mb for swap below.  :(","commit_id":"bfd7a93910857faf14eff45a5c8fc6389a58b364"},{"author":{"_account_id":1812,"name":"p-draigbrady","email":"P@draigBrady.com","username":"p-draigbrady"},"change_message_id":"ed4a3255169e2dc79889232d5f0de7eabea95477","unresolved":false,"context_lines":[{"line_number":932,"context_line":"                                  project_id\u003dinst[\u0027project_id\u0027])"},{"line_number":933,"context_line":""},{"line_number":934,"context_line":"        root_fname \u003d hashlib.sha1(str(disk_images[\u0027image_id\u0027])).hexdigest()"},{"line_number":935,"context_line":"        size \u003d inst[\u0027root_gb\u0027] * 1024 * 1024 * 1024"},{"line_number":936,"context_line":""},{"line_number":937,"context_line":"        inst_type_id \u003d inst[\u0027instance_type_id\u0027]"},{"line_number":938,"context_line":"        inst_type \u003d instance_types.get_instance_type(inst_type_id)"}],"source_content_type":"text/x-python","patch_set":1,"id":"AAAAEn%2F%2F%2F8A%3D","line":935,"in_reply_to":"AAAAEn%2F%2F%2F9c%3D","updated":"2012-02-02 10:23:07.000000000","message":"No that comes in a separate parameter (swap_mb).\n\nI left size as the full number, as it is also passed to _cache_image()\nfrom pre_block_migration().\nHowever that is passed a value from instance_ref[\u0027ephemeral_gb\u0027].\nThat looks inconsistent though. Shouldn\u0027t it be info[\u0027disk_size\u0027] ?","commit_id":"bfd7a93910857faf14eff45a5c8fc6389a58b364"},{"author":{"_account_id":67,"name":"Vish Ishaya","email":"vishvananda@gmail.com","username":"vishvananda"},"change_message_id":"0ea37930f65c8a065a2223d56feb3f15a290a3f3","unresolved":false,"context_lines":[{"line_number":937,"context_line":"        inst_type_id \u003d inst[\u0027instance_type_id\u0027]"},{"line_number":938,"context_line":"        inst_type \u003d instance_types.get_instance_type(inst_type_id)"},{"line_number":939,"context_line":"        if inst_type[\u0027name\u0027] \u003d\u003d \u0027m1.tiny\u0027 or suffix \u003d\u003d \u0027.rescue\u0027:"},{"line_number":940,"context_line":"            size \u003d 0"},{"line_number":941,"context_line":"            root_fname +\u003d \"_sm\""},{"line_number":942,"context_line":""},{"line_number":943,"context_line":"        if not self._volume_in_mapping(self.default_root_device,"}],"source_content_type":"text/x-python","patch_set":1,"id":"AAAAEn%2F%2F%2F9k%3D","line":940,"updated":"2012-02-02 07:24:15.000000000","message":"why did you change this to 0?  It is checked with if size: afaict so None should be fine?","commit_id":"bfd7a93910857faf14eff45a5c8fc6389a58b364"},{"author":{"_account_id":1812,"name":"p-draigbrady","email":"P@draigBrady.com","username":"p-draigbrady"},"change_message_id":"ed4a3255169e2dc79889232d5f0de7eabea95477","unresolved":false,"context_lines":[{"line_number":937,"context_line":"        inst_type_id \u003d inst[\u0027instance_type_id\u0027]"},{"line_number":938,"context_line":"        inst_type \u003d instance_types.get_instance_type(inst_type_id)"},{"line_number":939,"context_line":"        if inst_type[\u0027name\u0027] \u003d\u003d \u0027m1.tiny\u0027 or suffix \u003d\u003d \u0027.rescue\u0027:"},{"line_number":940,"context_line":"            size \u003d 0"},{"line_number":941,"context_line":"            root_fname +\u003d \"_sm\""},{"line_number":942,"context_line":""},{"line_number":943,"context_line":"        if not self._volume_in_mapping(self.default_root_device,"}],"source_content_type":"text/x-python","patch_set":1,"id":"AAAAEn%2F%2F%2F78%3D","line":940,"in_reply_to":"AAAAEn%2F%2F%2F9k%3D","updated":"2012-02-02 10:23:07.000000000","message":"To simplify the code. Well I was originally calculating size_gb outside the \u0027if size:\u0027 conditional. I suppose we might want to distinguish None and 0 in future.\nOK I\u0027ll change back to None","commit_id":"bfd7a93910857faf14eff45a5c8fc6389a58b364"},{"author":{"_account_id":67,"name":"Vish Ishaya","email":"vishvananda@gmail.com","username":"vishvananda"},"change_message_id":"0ea37930f65c8a065a2223d56feb3f15a290a3f3","unresolved":false,"context_lines":[{"line_number":938,"context_line":"        inst_type \u003d instance_types.get_instance_type(inst_type_id)"},{"line_number":939,"context_line":"        if inst_type[\u0027name\u0027] \u003d\u003d \u0027m1.tiny\u0027 or suffix \u003d\u003d \u0027.rescue\u0027:"},{"line_number":940,"context_line":"            size \u003d 0"},{"line_number":941,"context_line":"            root_fname +\u003d \"_sm\""},{"line_number":942,"context_line":""},{"line_number":943,"context_line":"        if not self._volume_in_mapping(self.default_root_device,"},{"line_number":944,"context_line":"                                       block_device_info):"}],"source_content_type":"text/x-python","patch_set":1,"id":"AAAAEn%2F%2F%2F9Y%3D","line":941,"updated":"2012-02-02 07:24:15.000000000","message":"I don\u0027t think we would be fine not calling it _sm anymore, but I guess this means that the existing cache will still work?","commit_id":"bfd7a93910857faf14eff45a5c8fc6389a58b364"},{"author":{"_account_id":1812,"name":"p-draigbrady","email":"P@draigBrady.com","username":"p-draigbrady"},"change_message_id":"ed4a3255169e2dc79889232d5f0de7eabea95477","unresolved":false,"context_lines":[{"line_number":938,"context_line":"        inst_type \u003d instance_types.get_instance_type(inst_type_id)"},{"line_number":939,"context_line":"        if inst_type[\u0027name\u0027] \u003d\u003d \u0027m1.tiny\u0027 or suffix \u003d\u003d \u0027.rescue\u0027:"},{"line_number":940,"context_line":"            size \u003d 0"},{"line_number":941,"context_line":"            root_fname +\u003d \"_sm\""},{"line_number":942,"context_line":""},{"line_number":943,"context_line":"        if not self._volume_in_mapping(self.default_root_device,"},{"line_number":944,"context_line":"                                       block_device_info):"}],"source_content_type":"text/x-python","patch_set":1,"id":"AAAAEn%2F%2F%2F74%3D","line":941,"in_reply_to":"AAAAEn%2F%2F%2F9Y%3D","updated":"2012-02-02 10:23:07.000000000","message":"Yes, I was thinking about existing cache, but I was more thinking that _sm was used to tag \u0027m1.tiny\u0027 and \u0027.rescue\u0027 images independent of size, and so thought it best to leave alone? I\u0027ll remove the _sm tag if you confirm.\n\nI guess Michael\u0027s cache cleanup patch would still need to look for _sm tagged files and clean those.","commit_id":"bfd7a93910857faf14eff45a5c8fc6389a58b364"},{"author":{"_account_id":2271,"name":"Michael Still","email":"mikal@stillhq.com","username":"mikalstill"},"change_message_id":"1138f576757c23ae62fa51d08c6321f587363d78","unresolved":false,"context_lines":[{"line_number":840,"context_line":"            elif generating:"},{"line_number":841,"context_line":"                # For raw it\u0027s quicker to just generate outside the cache"},{"line_number":842,"context_line":"                if os.path.exists(target):"},{"line_number":843,"context_line":"                    os.unlink(target)"},{"line_number":844,"context_line":"                call_if_not_exists(target, fn, *args, **kwargs)"},{"line_number":845,"context_line":""},{"line_number":846,"context_line":"            if cow:"}],"source_content_type":"text/x-python","patch_set":2,"id":"AAAAEn%2F%2F%2Bw0%3D","line":843,"updated":"2012-02-04 09:42:53.000000000","message":"Isn\u0027t this mutually exclusive with the test at the start of the method?","commit_id":"fc19fce8b5fca78fbf59465c8cc898c42de55820"}]}
